@@ -20,11 +20,10 @@
 //  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 //  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 //  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-"use strict";
 
-const expect = require("chai").expect;
-const espree = require("./util/espree");
-const analyze = require("..").analyze;
+import { expect } from "chai";
+import espree from "./util/espree.js";
+import { analyze } from "../lib/index.js";
 
 describe("ES6 super", () => {
     it("is not handled as reference", () => {
