@@ -20,15 +20,16 @@
 //  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 //  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 //  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-"use strict";
 
-const expect = require("chai").expect;
-const visit = require("esrecurse").visit;
-const espree = require("./util/espree");
-const analyze = require("..").analyze;
+import { expect } from "chai";
+import esrecurse from "esrecurse";
+import espree from "./util/espree.js";
+import { analyze } from "../lib/index.js";
+
+const { visit } = esrecurse;
 
 describe("ScopeManager.prototype.getDeclaredVariables", () => {
-    /* eslint-disable require-jsdoc */
+    /* eslint-disable jsdoc/require-jsdoc */
     function verify(ast, type, expectedNamesList) {
         const scopeManager = analyze(ast, {
             ecmaVersion: 6,
