@@ -20,16 +20,16 @@
 //  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 //  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 //  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-"use strict";
 
 /* eslint-disable no-unused-expressions */
 
-const expect = require("chai").expect;
-const espree = require("./util/espree");
-const analyze = require("..").analyze;
+import { expect } from "chai";
+import espree from "./util/espree.js";
+import { analyze } from "../lib/index.js";
 
 describe("nodejsScope option", () => {
-    it("creates a function scope following the global scope immediately", () => {
+
+    it("creates a function scope following the global scope immediately when nodejscope: true", () => {
         const ast = espree(`
             "use strict";
             var hello = 20;
@@ -55,6 +55,32 @@ describe("nodejsScope option", () => {
         expect(scope.variables[1].name).to.be.equal("hello");
     });
 
+    it("creates a function scope following the global scope immediately when sourceType:commonjs", () => {
+        const ast = espree(`
+            "use strict";
+            var hello = 20;
+        `);
+
+        const scopeManager = analyze(ast, { ecmaVersion: 6, sourceType: "commonjs" });
+
+        expect(scopeManager.scopes).to.have.length(2);
+
+        let scope = scopeManager.scopes[0];
+
+        expect(scope.type).to.be.equal("global");
+        expect(scope.block.type).to.be.equal("Program");
+        expect(scope.isStrict).to.be.false;
+        expect(scope.variables).to.have.length(0);
+
+        scope = scopeManager.scopes[1];
+        expect(scope.type).to.be.equal("function");
+        expect(scope.block.type).to.be.equal("Program");
+        expect(scope.isStrict).to.be.true;
+        expect(scope.variables).to.have.length(2);
+        expect(scope.variables[0].name).to.be.equal("arguments");
+        expect(scope.variables[1].name).to.be.equal("hello");
+    });
+
     it("creates a function scope following the global scope immediately and creates module scope", () => {
         const ast = espree("import {x as v} from 'mod';");
 
